'use strict';
Object.defineProperty(exports, '__esModule', { value: true });
const tslib_1 = require('tslib');
const path_1 = tslib_1.__importDefault(require('path'));
const worker_1 = tslib_1.__importDefault(require('../utils/worker'));
const utils_1 = require('../utils/index');
class Configuration {
    constructor(options) {
        this.options = options;
        this.init();
    }
    init() {
        const {stack, typescript, autoFix} = this.options;
        let config = this.loadStandardConfig('base');
        if (stack !== 'none') {
            const stackConfig = this.loadStandardConfig(stack);
            config = utils_1.merge(config, stackConfig);
        }
        if (typescript) {
            if (stack === 'vue') {
                const vueTypescriptConfig = this.loadStandardConfig('vue-typescript');
                config = utils_1.merge(config, vueTypescriptConfig);
            } else {
                const typescriptConfig = this.loadStandardConfig('none-typescript');
                config = utils_1.merge(config, typescriptConfig);
            }
        } else {
            const javascriptConfig = this.loadStandardConfig('javascript');
            config = utils_1.merge(config, javascriptConfig);
        }
        this.autoFix = autoFix;
        this.eslintConfig = config.eslint;
        this.prettierConfig = config.prettier;
        this.packageJsonConfig = config['package-json'];
    }
    loadStandardConfig(standard) {
        const baseConfigPath = path_1.default.join(worker_1.default.getOwnDir(), `./templates/standard/${ standard }.js`);
        return require(baseConfigPath);
    }
    getAutoFix() {
        return this.autoFix;
    }
    getPackageJsonConfig() {
        return this.packageJsonConfig;
    }
    getEslintConfig() {
        return this.eslintConfig;
    }
    getPrettierConfig() {
        return this.prettierConfig;
    }
}
exports.default = Configuration;