"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const boxen_1 = tslib_1.__importStar(require("boxen"));
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const inquirer_1 = tslib_1.__importDefault(require("inquirer"));
const shelljs_1 = tslib_1.__importDefault(require("shelljs"));
const configuration_1 = tslib_1.__importDefault(require("./configuration"));
const options_1 = tslib_1.__importStar(require("./options"));
const schedule_1 = tslib_1.__importDefault(require("./schedule"));
class Standard {
    async getOptions() {
        const answers = await inquirer_1.default.prompt(options_1.default);
        if (!answers.overrides)
            shelljs_1.default.exit(0);
        return Promise.resolve(answers);
    }
    async getAutoFixOption() {
        const answers = await inquirer_1.default.prompt(options_1.autoFixOption);
        console.log(answers);
        return Promise.resolve(answers.autoFix || false);
    }
    initial(options) {
        if (!options)
            return;
        const standardConfig = new configuration_1.default(options);
        const schedule = new schedule_1.default();
        schedule.initConfig(standardConfig);
        schedule.run();
        console.log(boxen_1.default(chalk_1.default.green(`
      项目规范已经初始化完成！
      如果你使用 vscode，推荐安装插件 ESLint 和 Prettier！
    `), { padding: 1, margin: 1, borderStyle: "double" /* Double */ }));
    }
    initVueStandard(config) {
        const options = {
            stack: 'vue',
            typescript: false,
            autoFix: true
        };
        options.autoFix = config.autoFix;
        this.initial(options);
    }
}
exports.default = async (options) => {
    const standard = new Standard();
    if (options.vue) {
        const autoFix = await standard.getAutoFixOption();
        standard.initVueStandard({ autoFix });
        return;
    }
    const configOptions = await standard.getOptions();
    standard.initial(configOptions);
};
