import 'module-alias/register';
import path from 'path';
import chalk from 'chalk';
import commander from 'commander';
import pkg from '../package.json';
import worker from './utils/worker';
import initStandard from './standard';
const { program } = commander;

const ownDir = path.resolve(
  __dirname,
  process.env.NODE_ENV === 'development' ? '../' : '../../'
);
worker.setOwnDir(ownDir);
worker.setWorkDir(process.cwd());

/**
 * 版本信息
 */
program
  .version(pkg.version, '-v --version')
  .description('Jgxl cli for efficient collaboration')
  .action(() => {
    console.log(chalk.green('Welcome to Jgxl Cli!'));
  });

/**
 * 生成配置文件
 */
program
  .command('standard')
  .option('-v --vue', 'quick config vue standard')
  .description('Initial standard config')
  .action(initStandard);

program.on('--help', () => {
  console.log();
  console.log(
    `  Run ${chalk.cyan(
      'jgxl <command> --help'
    )} for detailed usage of given command.`
  );
  console.log();
});

program.parse(process.argv);

if (!process.argv.slice(2).length) {
  program.outputHelp();
}

function logHelp() {
  console.log(`
  Commands:
  jgxl standard             Initial standard config`);
}
