import path from 'path';
import worker from '@/utils/worker';
import { merge } from '@/utils';

export type ConfigOptions = {
  stack: string;
  typescript: boolean;
  autoFix: boolean;
};

export default class Configuration {
  private options: ConfigOptions;
  private autoFix!: boolean;
  private eslintConfig: any;
  private prettierConfig: any;
  private packageJsonConfig: any;

  constructor(options: ConfigOptions) {
    this.options = options;
    this.init();
  }

  private init() {
    const { stack, typescript, autoFix } = this.options;
    let config = this.loadStandardConfig('base');
    if (stack !== 'none') {
      const stackConfig = this.loadStandardConfig(stack);
      config = merge(config, stackConfig);
    }

    if (typescript) {
      if (stack === 'vue') {
        const vueTypescriptConfig = this.loadStandardConfig('vue-typescript');
        config = merge(config, vueTypescriptConfig);
      } else {
        const typescriptConfig = this.loadStandardConfig('none-typescript');
        config = merge(config, typescriptConfig);
      }
    } else {
      const javascriptConfig = this.loadStandardConfig('javascript');
      config = merge(config, javascriptConfig);
    }

    this.autoFix = autoFix;
    this.eslintConfig = config.eslint;
    this.prettierConfig = config.prettier;
    this.packageJsonConfig = config['package-json'];
  }
  
  private loadStandardConfig(standard: string) {
    const baseConfigPath = path.join(worker.getOwnDir(), `./templates/standard/${standard}.js`);
    return require(baseConfigPath);
  }

  public getAutoFix(): boolean {
    return this.autoFix;
  }

  public getPackageJsonConfig() {
    return this.packageJsonConfig;
  }

  public getEslintConfig() {
    return this.eslintConfig;
  }

  public getPrettierConfig() {
    return this.prettierConfig;
  }
}
