import boxen, { BorderStyle } from 'boxen';
import chalk from 'chalk';
import inquirer from 'inquirer';
import shell from 'shelljs';
import Configuration, { ConfigOptions } from './configuration';
import options, { autoFixOption } from './options';
import Schedule from './schedule';

class Standard {
  public async getOptions(): Promise<ConfigOptions> {
    const answers = await inquirer.prompt(options);
    if (!answers.overrides) shell.exit(0);

    return Promise.resolve(answers as ConfigOptions);
  }

  public async getAutoFixOption(): Promise<boolean> {
    const answers: ConfigOptions = await inquirer.prompt(autoFixOption);
    console.log(answers);
    return Promise.resolve(answers.autoFix || false);
  } 

  public initial(options: ConfigOptions) {
    if (!options) return;

    const standardConfig = new Configuration(options);
    const schedule = new Schedule();
    schedule.initConfig(standardConfig);
    schedule.run();

    console.log(
      boxen(
        chalk.green(`
      项目规范已经初始化完成！
      如果你使用 vscode，推荐安装插件 ESLint 和 Prettier！
    `),
        { padding: 1, margin: 1, borderStyle: BorderStyle.Double }
      )
    );
  }

  public initVueStandard(config: any) {
    const options: ConfigOptions = {
      stack: 'vue',
      typescript: false,
      autoFix: true
    };
    options.autoFix = config.autoFix;
    this.initial(options);
  }
}

export default async (options: { vue: boolean }) => {
  const standard = new Standard();

  if (options.vue) {
    const autoFix = await standard.getAutoFixOption();
    standard.initVueStandard({ autoFix });
    return;
  }

  const configOptions = await standard.getOptions();
  standard.initial(configOptions);
};
