// 1. 安装 Eslint。
// 2. 根据项目类型安装对应的 ESLint 规则配置 npm 包。
// 3. 根据项目类型安装相关的插件、解析器等。
// 4. 根据项目类型配置 .eslintrc .prettierrc 文件。
// 5. 安装代码提交检查 + 自动格式化工具。 husky + lint-staged
// 6. 配置 package.json。
// 7. 测试及修复问题。

module.exports = {
  eslint: {
    root: true,

    parserOptions: {
      sourceType: 'module'
    },

    env: {
      browser: true,
      node: true,
      es6: true
    },

    extends: ['standard', 'prettier'],

    rules: {
      // Only disallow debugger in production
      'no-debugger': process.env.NODE_ENV === 'production' ? 'error' : 'off',
      // Only disallow `console.log` in production
      'no-console': 'off',
      // 单引号
      quotes: ['error', 'single'],
      // 代码结尾需要分号
      semi: ['error', 'always']
    }
  },

  eslintIgnore: [
    'src/**/*.less',
    'src/**/*.md'
  ],

  prettier: {
    printWidth: 120,
    tabWidth: 2,
    useTabs: false,
    semi: true,
    singleQuote: true,
    bracketSpacing: true,
    jsxBracketSameLine: false,
    arrowParens: 'avoid',
    proseWrap: 'never',
    trailingComma: 'none'
  },

  'package-json': {
    devDependencies: {
      eslint: '7.22.0',
      'babel-eslint': '10.1.0',
      standard: '16.0.3',
      prettier: '1.19.1',
      husky: '5.2.0',
      'lint-staged': '10.5.4',
      'eslint-config-prettier': '8.1.0',
      'eslint-plugin-standard': '5.0.0',
      'eslint-config-standard': '14.1.1'
    },
    scripts: {
      'jgxl-pre-commit': 'lint-staged'
    },
    'lint-staged': {
      'src/**': ['eslint --fix']
    }
  }
};
